@@ -1,9 +1,8 @@
-import argparse
-
-from pls.args import dev, filter, info, info_mod, meta, pos, pres, sort
+from pls.args import dev, filter, info, meta, pos, pres, sort
+from pls.args.base import PlsFormatter, PlsParser
 
 
-def _get_core_parser() -> argparse.ArgumentParser:
+def _get_core_parser() -> PlsParser:
     """
     Get an empty argument parser for ``pls``. This parser has no arguments or argument
     groups associated with it, yet.
@@ -11,21 +10,22 @@ def _get_core_parser() -> argparse.ArgumentParser:
     :return: the standard argument parser
     """
 
-    return argparse.ArgumentParser(
+    return PlsParser(
         prog="pls",
         description=(
             """
-            `pls` is a prettier and powerful `ls` for the pros.
+            [red bold]`pls`[/] is a prettier and powerful `ls` for the pros.
 
             You can read the docs at https://dhruvkb.github.io/pls and
             obtain the source code at https://github.com/dhruvkb/pls.
             """
         ),
+        formatter_class=PlsFormatter,
         add_help=False,  # added via the 'meta' group later
     )
 
 
-def get_parser() -> argparse.ArgumentParser:
+def get_parser() -> PlsParser:
     """
     Get the parser with all arguments configured on it.
 
@@ -34,7 +34,7 @@ def get_parser() -> argparse.ArgumentParser:
 
     core_parser = _get_core_parser()
 
-    arg_modules = [pos, meta, pres, info, info_mod, sort, filter, dev]
+    arg_modules = [pos, meta, pres, info, sort, filter, dev]
     for arg_module in arg_modules:
         adder = getattr(arg_module, "add_args")
         adder(core_parser)
