@@ -2,6 +2,8 @@ from __future__ import annotations
 
 from enum import auto
 
+from pls.config import constants
+from pls.data.utils import lookup
 from pls.enums.base import AutoEnum
 
 
@@ -29,22 +31,34 @@ class NodeType(AutoEnum):
     CHAR_DEVICE = auto()  # character special device file
     BLOCK_DEVICE = auto()  # block special device file
     UNKNOWN = auto()  # graceful handling of unrecognised type
+    BROKEN = auto()  # handling of non-existent nodes
 
 
 type_test_map: dict[NodeType, str] = {
     node_type: f"is_{node_type.value}"
     for node_type in list(NodeType)
-    if node_type != NodeType.UNKNOWN
+    if node_type not in {NodeType.UNKNOWN, NodeType.BROKEN}
 }
 """a mapping of node types with specific functions that evaluate it"""
 
-type_char_map: dict[NodeType, str] = {
-    NodeType.SYMLINK: "l",
-    NodeType.DIR: "d",
-    NodeType.FILE: "-",
-    NodeType.FIFO: "p",
-    NodeType.SOCKET: "s",
-    NodeType.CHAR_DEVICE: "c",
-    NodeType.BLOCK_DEVICE: "b",
-    NodeType.UNKNOWN: "?",
-}
+
+def get_type_char(node_type: NodeType) -> str:
+    """
+    Get the unique, distinct type character associated with the given node type. Returns
+    a blank string if no type character is associated.
+
+    :return: the type character mapped to the given ``NodeType`` value
+    """
+
+    return lookup(constants.constants, ["type_chars", node_type.value], "")
+
+
+def get_type_suffix(node_type: NodeType) -> str:
+    """
+    Get the unique, distinct type suffix associated with the given node type. Returns
+    a blank string if no type character is associated.
+
+    :return: the type suffix mapped to the given ``NodeType`` value
+    """
+
+    return lookup(constants.constants, ["type_suffixes", node_type.value], "")
