@@ -4,10 +4,10 @@ import re
 from functools import cached_property
 from typing import Optional, Union
 
-from pls import globals
-from pls.config.icons import emoji_icons, nerd_icons
+from pls.config import icons
 from pls.enums.icon_type import IconType
-from pls.enums.node_type import NodeType
+from pls.enums.node_type import NodeType, get_type_suffix
+from pls.globals import args
 from pls.models.base_node import BaseNode
 from pls.models.mixins.git import GitMixin
 from pls.models.mixins.imp import ImpMixin
@@ -97,25 +97,20 @@ class Node(
     def formatted_suffix(self) -> str:
         """the symbol after the filename representing its type"""
 
-        if not self.exists:
-            return "⚠"
-
+        node_type = self.node_type if self.exists else NodeType.BROKEN
+        suffix = get_type_suffix(node_type)
         if self.node_type == NodeType.SYMLINK:
+            if suffix:
+                suffix = f"{suffix} "
             assert self.dest_node is not None
 
             if self.is_loop:
                 assert isinstance(self.dest_node, str)
-                return f"[dim]@ ↺[/] [red]{self.dest_node}[/red]"
+                return f"[dim]{suffix}↺[/] [red]{self.dest_node}[/red]"
 
             assert isinstance(self.dest_node, Node)
-            return f"[dim]@ →[/] {self.dest_node.formatted_name}"
+            return f"[dim]{suffix}→[/] {self.dest_node.formatted_name}"
 
-        mapping = {
-            NodeType.DIR: "/",
-            NodeType.SOCKET: "=",
-            NodeType.FIFO: "|",
-        }
-        suffix = mapping.get(self.node_type, "")
         if suffix:
             suffix = f"[dim]{suffix}[/]"
         return suffix
@@ -124,7 +119,7 @@ class Node(
     def formatted_name(self) -> str:
         """the name, formatted using Rich console formatting markup"""
 
-        name = self.name if globals.state.no_align else self.pure_name
+        name = self.pure_name if args.args.align else self.name
         if self.formatted_suffix:
             name = f"{name}{self.formatted_suffix}"
 
@@ -132,7 +127,7 @@ class Node(
         left, right = self.format_pair
         name = f"{left}{name}{right}"
 
-        if not globals.state.no_align and not self.is_pseudo:
+        if args.args.align and not self.is_pseudo:
             if re.match(r"\.[^.]", self.name):
                 name = f"[dim].[/dim]{name}"
             else:
@@ -148,13 +143,13 @@ class Node(
     def formatted_icon(self) -> str:
         """the emoji or Nerd Font icon to show beside the node"""
 
-        if globals.state.icon == IconType.NONE:
+        if args.args.icon == IconType.NONE:
             return ""
 
-        if globals.state.icon == IconType.EMOJI:
-            icon_index = emoji_icons
-        else:  # args.icon == IconType.NERD
-            icon_index = nerd_icons
+        if args.args.icon == IconType.EMOJI:
+            icon_index = icons.emoji_icons
+        else:  # args.args.icon == IconType.NERD (default)
+            icon_index = icons.nerd_icons
 
         if spec_icon := self.spec_attr("icon"):
             icon = icon_index.get(str(spec_icon))
@@ -171,6 +166,13 @@ class Node(
             icon = ""
         return icon
 
+    @cached_property
+    def formatted_type_char(self) -> str:
+        """the type character associated with the type of the node"""
+
+        left, right = self.format_pair
+        return f"{left}{self.type_char}{right}"
+
     @cached_property
     def table_row(self) -> Optional[dict[str, Optional[str]]]:
         """the mapping of column names and value when tabulating the node"""
@@ -182,10 +184,10 @@ class Node(
         cells: dict[str, Optional[str]] = {
             "name": self.formatted_name,
             "icon": self.formatted_icon,
-            "type": self.type_char,
+            "type": self.formatted_type_char,
         }
 
-        if not globals.state.details:
+        if not args.args.details:
             return cells  # return early as no more data needed
 
         cells.update(self.stat_cells)
